@@ -173,6 +173,21 @@
         <source>Sort</source>
         <translation>ترتيب</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Paste from clipboard</source>
+        <translation>لصق من الحافظة</translation>
+    </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Cut from clipboard</source>
+        <translation>قطع من الحافظة</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>ERROR: Nothing selected to paste</source>
+        <translation>خطأ : لا شيء مختارة للصق</translation>
+    </message>
 </context>
 <context>
     <name>Share</name>
@@ -816,6 +831,11 @@
         <source>Cancel</source>
         <translation>إلغاء</translation>
     </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Password</source>
+        <translation>كلمة السر</translation>
+    </message>
 </context>
 <context>
     <name>Extract</name>
@@ -834,6 +854,11 @@
         <source>Operation finished.</source>
         <translation>تمت العملية بنجاح.</translation>
     </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Error extracting files. Incorrect password?</source>
+        <translation>ملفات استخراج خطأ. غير صحيح كلمة السر؟</translation>
+    </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Cancel</source>
