@@ -173,6 +173,21 @@
         <source>Sort</source>
         <translation>Järjestä</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Paste from clipboard</source>
+        <translation>Liitä leikepöydältä</translation>
+    </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Cut from clipboard</source>
+        <translation>Leikkaa leikepöydältä</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>ERROR: Nothing selected to paste</source>
+        <translation>VIRHE: Ei liitettävää</translation>
+    </message>
 </context>
 <context>
     <name>Share</name>
@@ -816,6 +831,11 @@
         <source>Cancel</source>
         <translation>Peru</translation>
     </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Password</source>
+        <translation>Salasana</translation>
+    </message>
 </context>
 <context>
     <name>Extract</name>
@@ -834,6 +854,11 @@
         <source>Operation finished.</source>
         <translation>Purkaminen suoritettu.</translation>
     </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Error extracting files. Incorrect password?</source>
+        <translation>Virhe purettaessa tiedostoa. Virheellinen salasana?</translation>
+    </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Cancel</source>
