@@ -173,6 +173,21 @@
         <source>Sort</source>
         <translation>Trier</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Paste from clipboard</source>
+        <translation>Coller à partir du presse-papiers</translation>
+    </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Cut from clipboard</source>
+        <translation>Couper dans le presse-papiers</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>ERROR: Nothing selected to paste</source>
+        <translation>ERREUR: Rien n&apos;a été selectionner</translation>
+    </message>
 </context>
 <context>
     <name>Share</name>
@@ -816,6 +831,11 @@
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Password</source>
+        <translation>Mot de passe</translation>
+    </message>
 </context>
 <context>
     <name>Extract</name>
@@ -834,6 +854,11 @@
         <source>Operation finished.</source>
         <translation>Opération terminée.</translation>
     </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Error extracting files. Incorrect password?</source>
+        <translation>Erreur d'extraction des fichiers. Mot de passe incorrect?</translation>
+    </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Cancel</source>
