@@ -173,6 +173,21 @@
         <source>Sort</source>
         <translation>Ordenar</translation>
     </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Paste from clipboard</source>
+        <translation>Pegar del portapapeles</translation>
+    </message>
+    <message>
+        <location filename="../toolsdialog.cpp" line="10"/>
+        <source>Cut from clipboard</source>
+        <translation>Cortar del portapapeles</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="10"/>
+        <source>ERROR: Nothing selected to paste</source>
+        <translation>ERROR: Nada seleccionado para pegar</translation>
+    </message>
 </context>
 <context>
     <name>Share</name>
@@ -816,6 +831,11 @@
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Password</source>
+        <translation>Clave de acceso</translation>
+    </message>
 </context>
 <context>
     <name>Extract</name>
@@ -834,6 +854,11 @@
         <source>Operation finished.</source>
         <translation>Operación terminada.</translation>
     </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Error extracting files. Incorrect password?</source>
+        <translation>Error al extraer los archivos. Contraseña incorrecta?</translation>
+    </message>
     <message>
         <location filename="../extract.cpp" line="10"/>
         <source>Cancel</source>
